@@ -1,10 +1,12 @@
 package App::TimeTracker::Command::Core;
+
+# ABSTRACT: App::TimeTracker Core commands
+our $VERSION = '3.008'; # VERSION
+
 use strict;
 use warnings;
 use 5.010;
 
-# ABSTRACT: App::TimeTracker Core commands
-
 use Moose::Role;
 use Moose::Util::TypeConstraints;
 use App::TimeTracker::Utils qw(now pretty_date error_message);
@@ -661,7 +663,7 @@ App::TimeTracker::Command::Core - App::TimeTracker Core commands
 
 =head1 VERSION
 
-version 3.007
+version 3.008
 
 =head1 CORE COMMANDS
 
@@ -900,11 +902,11 @@ List all available commands, based on your current config.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Thomas Klausner.
+This software is copyright (c) 2011 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
