@@ -1,10 +1,12 @@
 package App::TimeTracker::Constants;
+
+# ABSTRACT: App::TimeTracker pre-defined constants
+our $VERSION = '3.008'; # VERSION
+
 use strict;
 use warnings;
 use 5.010;
 
-# ABSTRACT: App::TimeTracker pre-defined constants
-
 use Exporter;
 use parent qw(Exporter);
 
@@ -29,7 +31,7 @@ App::TimeTracker::Constants - App::TimeTracker pre-defined constants
 
 =head1 VERSION
 
-version 3.007
+version 3.008
 
 =head1 DESCRIPTION
 
@@ -37,11 +39,11 @@ Pre-defined constants used without the module's internals.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Thomas Klausner.
+This software is copyright (c) 2011 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
