@@ -1,7 +1,9 @@
 package App::TimeTracker::Data::Task;
-use 5.010;
 
 # ABSTRACT: App::TimeTracker Task storage
+our $VERSION = '3.008'; # VERSION
+
+use 5.010;
 
 use Moose;
 use App::TimeTracker::Utils qw(now);
@@ -10,8 +12,8 @@ use App::TimeTracker;
 use DateTime::Format::ISO8601;
 use DateTime::Format::Duration;
 use User::pwent;
-
 use MooseX::Storage;
+
 with Storage(
     format => [ JSONpm => { json_opts => { pretty => 1, canonical => 1 } } ],
     io     => "File",
@@ -219,7 +221,7 @@ App::TimeTracker::Data::Task - App::TimeTracker Task storage
 
 =head1 VERSION
 
-version 3.007
+version 3.008
 
 =head1 DESCRIPTION
 
@@ -227,11 +229,11 @@ Rather boring class implementing a Task object. Mainly used for storage etc.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Thomas Klausner.
+This software is copyright (c) 2011 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
