@@ -1,13 +1,14 @@
 package App::TimeTracker::Utils;
+
+# ABSTRACT: Utility Methods/Functions for App::TimeTracker
+our $VERSION = '3.008'; # VERSION
+
 use strict;
 use warnings;
 use 5.010;
 
-# ABSTRACT: Utility Methods/Functions for App::TimeTracker
-
 use Scalar::Util qw(blessed);
 use Term::ANSIColor;
-
 use Exporter;
 use parent qw(Exporter);
 
@@ -75,15 +76,15 @@ App::TimeTracker::Utils - Utility Methods/Functions for App::TimeTracker
 
 =head1 VERSION
 
-version 3.007
+version 3.008
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Thomas Klausner.
+This software is copyright (c) 2011 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
